@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +40,8 @@ public:
 	void set_devices( std::vector<Device> & devices ) ;
 	
 	bool snap_to_cylinder( const Device & device, Partition & partition, Glib::ustring & error ) ;
+	bool snap_to_mebibyte( const Device & device, Partition & partition, Glib::ustring & error ) ;
+	bool snap_to_alignment( const Device & device, Partition & partition, Glib::ustring & error ) ;
 	bool apply_operation_to_disk( Operation * operation );
 	
 	bool set_disklabel( const Glib::ustring & device_path, const Glib::ustring & disklabel ) ;
@@ -71,6 +73,7 @@ private:
 				 std::vector<Partition> & partitions,
 				 Sector start,
 				 Sector end,
+				 Byte_Value sector_size,
 				 bool inside_extended ) ;
 	void set_mountpoints( std::vector<Partition> & partitions ) ;
 	void set_used_sectors( std::vector<Partition> & partitions ) ;
@@ -116,7 +119,7 @@ private:
 				
 	bool copy( const Partition & partition_src,
 		   Partition & partition_dst,
-		   Sector min_size,
+		   Byte_Value min_size,
 		   OperationDetail & operationdetail ) ; 
 	bool copy_filesystem_simulation( const Partition & partition_src,
 			      		 const Partition & partition_dst,
@@ -128,19 +131,21 @@ private:
 	bool copy_filesystem( const Partition & partition_src,
 			      const Partition & partition_dst,
 			      OperationDetail & operationdetail,
-			      Sector & total_done ) ;
+			      Byte_Value & total_done ) ;
 	bool copy_filesystem( const Glib::ustring & src_device,
 			      const Glib::ustring & dst_device,
 			      Sector src_start,
 			      Sector dst_start,
-			      Sector length,
+			      Byte_Value src_sector_size,
+			      Byte_Value dst_sector_size,
+			      Byte_Value src_length,
 			      OperationDetail & operationdetail,
 			      bool readonly,
-			      Sector & total_done ) ;
+			      Byte_Value & total_done ) ;
 	void rollback_transaction( const Partition & partition_src,
-			      	   const Partition & partition_dst,
-			      	   OperationDetail & operationdetail,
-			      	   Sector total_done ) ;
+				   const Partition & partition_dst,
+				   OperationDetail & operationdetail,
+				   Byte_Value total_done ) ;
 
 	bool check_repair_filesystem( const Partition & partition, OperationDetail & operationdetail ) ;
 
@@ -152,17 +157,17 @@ private:
 			  const Glib::ustring & dst_device,
 			  Sector src_start,
 			  Sector dst_start,
-			  Sector length,
-			  Sector blocksize,
+			  Byte_Value length,
+			  Byte_Value blocksize,
 			  OperationDetail & operationdetail,
 			  bool readonly,
-			  Sector & total_done ) ;
+			  Byte_Value & total_done ) ;
 
 	bool copy_block( PedDevice * lp_device_src,
 			 PedDevice * lp_device_dst,
 			 Sector offset_src,
 			 Sector offset_dst,
-			 Sector blocksize,
+			 Byte_Value blocksize,
 			 Glib::ustring & error_message,
 			 bool readonly ) ; 
 	bool calibrate_partition( Partition & partition, OperationDetail & operationdetail ) ;
