@@ -1,4 +1,5 @@
-/*	Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Bart Hakvoort
+/* Copyright (C) 2004 Bart
+ * Copyright (C) 2008, 2009 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -141,7 +142,7 @@ private:
 	void menu_view_harddisk_info();
 	void menu_view_operations();
 	void show_disklabel_unrecognized( Glib::ustring device_name );
-	void show_help_dialog (const char *link_id);
+	void show_help_dialog( const Glib::ustring & filename, const Glib::ustring & link_id );
 	void menu_help_contents();
 	void menu_help_about();
 
