@@ -1,4 +1,5 @@
 /* Copyright (C) 2004 Bart
+ * Copyright (C) 2008 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,16 +28,16 @@ namespace GParted
 class linux_swap : public FileSystem
 {
 public:
-	FS get_filesystem_support( ) ;
-	void Set_Used_Sectors( Partition & partition ) ;
-	bool Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details ) ;
-	bool Resize( const Partition & partition_new,
-		     std::vector<OperationDetails> & operation_details,
-		     bool fill_partition = false ) ;
-	bool Copy( const Glib::ustring & src_part_path,
+	FS get_filesystem_support() ;
+	void set_used_sectors( Partition & partition ) ;
+	void read_label( Partition & partition ) ;
+	bool write_label( const Partition & partition, OperationDetail & operationdetail ) ;
+	bool create( const Partition & new_partition, OperationDetail & operationdetail ) ;
+	bool resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition = false ) ;
+	bool copy( const Glib::ustring & src_part_path,
 		   const Glib::ustring & dest_part_path,
-		   std::vector<OperationDetails> & operation_details ) ;
-	bool Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details ) ;
+		   OperationDetail & operationdetail ) ;
+	bool check_repair( const Partition & partition, OperationDetail & operationdetail ) ;
 };
 
 } //GParted
