@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008, 2009 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,13 +24,12 @@ namespace GParted
 Dialog_Base_Partition::Dialog_Base_Partition()
 {
 	this ->set_has_separator( false ) ;
-//FIXME: somehow the 'off by a few' MiB's warning disappeared.
-//I need to display it whenever the round to cylinders isn't checked.
 	frame_resizer_base = NULL;
 	GRIP = false ;
 	this ->fixed_start = false ;
 	this ->set_resizable( false );
 	ORIG_BEFORE = ORIG_SIZE = ORIG_AFTER = -1 ;
+	MIN_SPACE_BEFORE_MB = -1 ;
 	
 	//pack resizer hbox
 	this ->get_vbox() ->pack_start( hbox_resizer, Gtk::PACK_SHRINK );
@@ -79,11 +78,6 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 	if ( ! fixed_start )
 		before_value = spinbutton_before .get_value() ;
 
-	//add checkbutton
-	checkbutton_round_to_cylinders .set_label( _("Round to cylinders") ) ;
-	checkbutton_round_to_cylinders .set_active( true ) ;
-	table_resize.attach( checkbutton_round_to_cylinders, 0, 1, 3, 4 ) ;
-
 	//connect signalhandlers of the spinbuttons
 	if ( ! fixed_start )
 		spinbutton_before .signal_value_changed() .connect( 
@@ -97,6 +91,24 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 		sigc::bind<SPINBUTTON>( 
 			sigc::mem_fun(*this, &Dialog_Base_Partition::on_spinbutton_value_changed), AFTER ) ) ;
 
+	//add alignment
+	/*TO TRANSLATORS: used as label for a list of choices.   Align to: <optionmenu with choices> */
+	table_resize .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("Align to:") ) + "\t" ),
+	                      0, 1, 3, 4, Gtk::FILL );
+
+	//fill partition alignment menu
+	/*TO TRANSLATORS: Menu option for drop down menu "Align to:" */
+	menu_alignment .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("Cylinder") ) ) ;
+	/*TO TRANSLATORS: Menu option for label "Align to:" */
+	menu_alignment .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("MiB") ) ) ;
+	/*TO TRANSLATORS: Menu option for drop down menu "Align to:" */
+	menu_alignment .items() .push_back( Gtk::Menu_Helpers::MenuElem( _("None") ) ) ;
+
+	optionmenu_alignment .set_menu( menu_alignment );
+	optionmenu_alignment .set_history( ALIGN_MEBIBYTE );  //Default setting
+
+	table_resize .attach( optionmenu_alignment, 1, 2, 3, 4, Gtk::FILL );
+
 	this->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 	this ->show_all_children() ;
 }
@@ -122,16 +134,21 @@ void Dialog_Base_Partition::Set_Resizer( bool extended )
 	this ->show_all_children() ;
 }
 
-Partition Dialog_Base_Partition::Get_New_Partition() 
+Partition Dialog_Base_Partition::Get_New_Partition( Byte_Value sector_size ) 
 {
+	//set sector size of new partition
+	selected_partition .sector_size = sector_size;
+
 	//FIXME:  Partition size is limited to just less than 1024 TeraBytes due
 	//        to the maximum value of signed 4 byte integer.
 	if ( ORIG_BEFORE != spinbutton_before .get_value_as_int() )
-		selected_partition .sector_start = START + Sector(spinbutton_before .get_value_as_int()) * MEBIBYTE ;	
+		selected_partition .sector_start = START + Sector(spinbutton_before .get_value_as_int()) * (MEBIBYTE / sector_size) ;	
 
 	if ( ORIG_AFTER != spinbutton_after .get_value_as_int() )
-		selected_partition .sector_end = 
-			selected_partition .sector_start + Sector(spinbutton_size .get_value_as_int()) * MEBIBYTE ;
+		selected_partition .sector_end =
+			selected_partition .sector_start
+			+ Sector(spinbutton_size .get_value_as_int()) * (MEBIBYTE / sector_size)
+			- 1 /* one sector short of exact mebibyte multiple */;
 
 	//due to loss of precision during calcs from Sector -> MiB and back, it is possible
 	//the new partition thinks it's bigger then it can be. Here we solve this.
@@ -141,17 +158,26 @@ Partition Dialog_Base_Partition::Get_New_Partition()
 		selected_partition .sector_end = START + total_length -1 ;
 	
 	//grow a bit into small freespace ( < 1MiB ) 
-	if ( (selected_partition .sector_start - START) < MEBIBYTE )
+	if ( (selected_partition .sector_start - START) < (MEBIBYTE / sector_size) )
 		selected_partition .sector_start = START ;
-	if ( ( START + total_length -1 - selected_partition .sector_end ) < MEBIBYTE )
+	if ( ( START + total_length -1 - selected_partition .sector_end ) < (MEBIBYTE / sector_size) )
 		selected_partition .sector_end = START + total_length -1 ;
 	
 	//set new value of unused..
 	if ( selected_partition .sectors_used != -1 )
-		selected_partition .sectors_unused = selected_partition .get_length() - selected_partition .sectors_used ;
+		selected_partition .sectors_unused = selected_partition .get_sector_length() - selected_partition .sectors_used ;
 
-	//set indicator of whether to use strict sector values, or to round to cylinders
-	selected_partition .strict = ! checkbutton_round_to_cylinders .get_active() ;
+	//set alignment
+	switch ( optionmenu_alignment .get_history() )
+	{
+		case  0 :  selected_partition .alignment = ALIGN_CYLINDER;  break;
+		case  1 :  selected_partition .alignment = ALIGN_MEBIBYTE;  break;
+		case  2 :  selected_partition .alignment = ALIGN_STRICT;  break;
+
+		default :  selected_partition .alignment = ALIGN_CYLINDER ;
+	}
+
+	selected_partition .free_space_before = Sector(spinbutton_before .get_value_as_int()) * (MEBIBYTE / sector_size) ;
 
 	//if the original before value has not changed, then set indicator to keep start sector unchanged
 	if ( ORIG_BEFORE == spinbutton_before .get_value_as_int() )
@@ -193,11 +219,29 @@ void Dialog_Base_Partition::Set_MinMax_Text( Sector min, Sector max )
 	label_minmax .set_text( str_temp ) ; 
 }
 
+int Dialog_Base_Partition::MB_Needed_for_Boot_Record( const Partition & partition )
+{
+	//Determine if space is needed for the Master Boot Record or
+	//  the Extended Boot Record.  Generally an an additional track or MEBIBYTE
+	//  is required so for our purposes reserve a MEBIBYTE in front of the partition.
+	//  NOTE:  This logic also contained in Win_GParted::set_valid_operations
+	if (   (   partition .inside_extended
+	        && partition .type == TYPE_UNALLOCATED
+	       )
+	    || ( partition .type == TYPE_LOGICAL )
+	                                     /* Beginning of disk device */
+	    || ( partition .sector_start <= (MEBIBYTE / partition .sector_size) )
+	   )
+		return 1 ;
+	else
+		return 0 ;
+}
+
 void Dialog_Base_Partition::on_signal_move( int x_start, int x_end )
 {  
 	GRIP = true ;
 
-	spinbutton_before .set_value( x_start == 0 ? 0 : x_start * MB_PER_PIXEL ) ;
+	spinbutton_before .set_value( x_start <= MIN_SPACE_BEFORE_MB * MB_PER_PIXEL ? MIN_SPACE_BEFORE_MB : x_start * MB_PER_PIXEL ) ;
 	
 	if ( x_end == 500 )
 	{
@@ -218,7 +262,7 @@ void Dialog_Base_Partition::on_signal_resize( int x_start, int x_end, Frame_Resi
 		
 	spinbutton_size .set_value( ( x_end - x_start ) * MB_PER_PIXEL ) ;
 	
-	before_value = fixed_start ? 0 : spinbutton_before .get_value() ;
+	before_value = fixed_start ? MIN_SPACE_BEFORE_MB : spinbutton_before .get_value() ;
 
 	if ( arrow == Frame_Resizer_Base::ARROW_RIGHT ) //don't touch freespace before, leave it as it is
 	{
@@ -232,10 +276,10 @@ void Dialog_Base_Partition::on_signal_resize( int x_start, int x_end, Frame_Resi
 	}
 	else if ( arrow == Frame_Resizer_Base::ARROW_LEFT ) //don't touch freespace after, leave it as it is
 	{
-		if ( x_start == 0 )
+		if ( x_start <= MIN_SPACE_BEFORE_MB * MB_PER_PIXEL )
 		{
-			spinbutton_before .set_value( 0 );
-			spinbutton_size .set_value( TOTAL_MB - spinbutton_after.get_value() ) ;
+			spinbutton_before .set_value( MIN_SPACE_BEFORE_MB );
+			spinbutton_size .set_value( TOTAL_MB - MIN_SPACE_BEFORE_MB - spinbutton_after.get_value() ) ;
 		}
 		else
 			spinbutton_before .set_value(
@@ -251,7 +295,7 @@ void Dialog_Base_Partition::on_spinbutton_value_changed( SPINBUTTON spinbutton )
 {  
 	if ( ! GRIP )
 	{
-		before_value = fixed_start ? 0 : spinbutton_before .get_value() ;
+		before_value = fixed_start ? MIN_SPACE_BEFORE_MB : spinbutton_before .get_value() ;
 			
 		//Balance the spinbuttons
 		switch ( spinbutton )
