@@ -167,34 +167,34 @@ Glib::ustring Utils::get_filesystem_software( FILESYSTEM filesystem )
 	}
 }
 
-Glib::ustring Utils::format_size( Sector size )
+Glib::ustring Utils::format_size( Sector sectors, Byte_Value sector_size )
 {
 	std::stringstream ss ;
 	ss << std::setiosflags( std::ios::fixed ) << std::setprecision( 2 ) ;
 
-	if ( size < KIBIBYTE )
+	if ( (sectors * sector_size) < KIBIBYTE )
 	{
-		ss << sector_to_unit( size, UNIT_BYTE ) ;
+		ss << sector_to_unit( sectors, sector_size, UNIT_BYTE ) ;
 		return String::ucompose( _("%1 B"), ss .str() ) ;
 	}
-	else if ( size < MEBIBYTE )
+	else if ( (sectors * sector_size) < MEBIBYTE )
 	{
-		ss << sector_to_unit( size, UNIT_KIB ) ;
+		ss << sector_to_unit( sectors, sector_size, UNIT_KIB ) ;
 		return String::ucompose( _("%1 KiB"), ss .str() ) ;
 	}
-	else if ( size < GIBIBYTE )
+	else if ( (sectors * sector_size) < GIBIBYTE )
 	{
-		ss << sector_to_unit( size, UNIT_MIB ) ;
+		ss << sector_to_unit( sectors, sector_size, UNIT_MIB ) ;
 		return String::ucompose( _("%1 MiB"), ss .str() ) ;
 	}
-	else if ( size < TEBIBYTE )
+	else if ( (sectors * sector_size) < TEBIBYTE )
 	{
-		ss << sector_to_unit( size, UNIT_GIB ) ;
+		ss << sector_to_unit( sectors, sector_size, UNIT_GIB ) ;
 		return String::ucompose( _("%1 GiB"), ss .str() ) ;
 	}
 	else
 	{
-		ss << sector_to_unit( size, UNIT_TIB ) ;
+		ss << sector_to_unit( sectors, sector_size, UNIT_TIB ) ;
 		return String::ucompose( _("%1 TiB"), ss .str() ) ;
 	}
 }
@@ -222,21 +222,21 @@ Glib::ustring Utils::format_time( std::time_t seconds )
 	return time ;
 }
 
-double Utils::sector_to_unit( Sector sectors, SIZE_UNIT size_unit )
+double Utils::sector_to_unit( Sector sectors, Byte_Value sector_size, SIZE_UNIT size_unit )
 {
 	switch ( size_unit )
 	{
 		case UNIT_BYTE	:
-			return sectors * 512 ;
+			return sectors * sector_size ;
 
 		case UNIT_KIB	:
-			return sectors / static_cast<double>( KIBIBYTE ) ;
+			return sectors / ( static_cast<double>( KIBIBYTE ) / sector_size );
 		case UNIT_MIB	:
-			return sectors / static_cast<double>( MEBIBYTE ) ;
+			return sectors / ( static_cast<double>( MEBIBYTE ) / sector_size );
 		case UNIT_GIB	:
-			return sectors / static_cast<double>( GIBIBYTE ) ;
+			return sectors / ( static_cast<double>( GIBIBYTE ) / sector_size );
 		case UNIT_TIB	:
-			return sectors / static_cast<double>( TEBIBYTE ) ;
+			return sectors / ( static_cast<double>( TEBIBYTE ) / sector_size );
 
 		default:
 			return sectors ;
