@@ -565,12 +565,12 @@ void Win_GParted::refresh_combo_devices()
 		treerow[ treeview_devices_columns .icon ] =
 			render_icon( Gtk::Stock::HARDDISK, Gtk::ICON_SIZE_LARGE_TOOLBAR ) ;
 		treerow[ treeview_devices_columns .device ] = devices[ i ] .get_path() ;
-		treerow[ treeview_devices_columns .size ] = "(" + Utils::format_size( devices[ i ] .length ) + ")" ; 
+		treerow[ treeview_devices_columns .size ] = "(" + Utils::format_size( devices[ i ] .length, devices[ i ] .sector_size ) + ")" ; 
 	
 		//devices submenu....
 		hbox = manage( new Gtk::HBox() ) ;
 		hbox ->pack_start( * Utils::mk_label( devices[ i ] .get_path() ), Gtk::PACK_SHRINK ) ;
-		hbox ->pack_start( * Utils::mk_label( "   (" + Utils::format_size( devices[ i ] .length ) + ")",
+		hbox ->pack_start( * Utils::mk_label( "   (" + Utils::format_size( devices[ i ] .length, devices[ i ] .sector_size ) + ")",
 					              true,
 						      Gtk::ALIGN_RIGHT ),
 				   Gtk::PACK_EXPAND_WIDGET ) ;
@@ -645,7 +645,7 @@ void Win_GParted::Fill_Label_Device_Info( bool clear )
 		
 		//global info...
 		device_info[ t++ ] ->set_text( devices[ current_device ] .model ) ;
-		device_info[ t++ ] ->set_text( Utils::format_size( devices[ current_device ] .length ) ) ;
+		device_info[ t++ ] ->set_text( Utils::format_size( devices[ current_device ] .length, devices[ current_device ] .sector_size ) ) ;
 		device_info[ t++ ] ->set_text( Glib::build_path( "\n", devices[ current_device ] .get_paths() ) ) ;
 		
 		//detailed info
@@ -669,10 +669,12 @@ void Win_GParted::Add_Operation( Operation * operation, int index )
 	{ 
 		Glib::ustring error ;
 		//FIXME: this is becoming a mess.. maybe it's better to check if partition_new > 0
-		if ( operation ->type == OPERATION_DELETE || 
-		     operation ->type == OPERATION_FORMAT || 
+		if ( operation ->type == OPERATION_DELETE ||
+		     operation ->type == OPERATION_FORMAT ||
 		     operation ->type == OPERATION_CHECK ||
-		     gparted_core .snap_to_cylinder( operation ->device, operation ->partition_new, error ) )
+		     operation ->type == OPERATION_LABEL_PARTITION ||
+		     gparted_core .snap_to_alignment( operation ->device, operation ->partition_new, error )
+		   )
 		{
 			operation ->create_description() ;
 
@@ -852,54 +854,50 @@ void Win_GParted::set_valid_operations()
 		//find out if there is a copied partition and if it fits inside this unallocated space
 		if ( ! copied_partition .get_path() .empty() && ! devices[ current_device ] .readonly )
 		{
-			Sector required_size ;
+			Byte_Value required_size ;
 			if ( copied_partition .filesystem == GParted::FS_XFS )
-				required_size = copied_partition .sectors_used ;
+				required_size = copied_partition .sectors_used * copied_partition .sector_size;
 			else
-				required_size = copied_partition .get_length() ;
+				required_size = copied_partition .get_byte_length() ;
 
-			//  /* Copy Primary not at start of disk to within Extended partition */
-			//  Adjust when a primary partition is copied and pasted
-			//  into an unallocated space in an extended partition
-			//  of an MSDOS partition table.
-			//  Since the Extended Boot Record requires an additional track,
-			//  this must be considered in the required space for the
-			//  destination (selected) partition.
-			//  NOTE:  This problem does not occur for a primary partition
-			//  at the the start of the disk because the size of the EBR and
-			//  Master Boot Record are the same.
-			//
-			//  /* Copy Primary not at start of disk to Primary at start of disk */
-			//  Also Adjust when a primary partition that does not start at the
-			//  beginning of the disk is copied and pasted
-			//  into an unallocated space at the start of the disk device.
-			//  Since the Master Boot Record requires an additional track,
-			//  this must be considered in the required space for the
-			//  destination (selected) partition.
-			//
-			//  Because the largest unit used in the GUI is one
-			//  cylinder size (round to cylinders), the space
-			//  needed in the destination partition needs to be increased
-			//  by one cylinder size.
-			if (   (/* Copy Primary not at start of disk to within Extended partition */
-				       copied_partition .type == TYPE_PRIMARY
-				    && copied_partition .sector_start > devices[ current_device ] .sectors /* 63 for MSDOS Partition Table */
-				    && devices[ current_device ] .disktype == "msdos" 
-				    && selected_partition .type == TYPE_UNALLOCATED
-				    && selected_partition .inside_extended
-				   )
-				|| ( /* Copy Primary not at start of disk to Primary at start of disk */
-				       copied_partition .type == TYPE_PRIMARY
-				    && copied_partition .sector_start > devices[ current_device ] .sectors /* 63 for MSDOS Partition Table */
-				    && devices[ current_device ] .disktype == "msdos" 
-				    && selected_partition .type == TYPE_UNALLOCATED
-				    && selected_partition .sector_start <= devices[ current_device ] .sectors  /* Beginning of disk device */
-				    && ! selected_partition .inside_extended
-				   )
+			//Determine if space is needed for the Master Boot Record or
+			//  the Extended Boot Record.  Generally an an additional track or MEBIBYTE
+			//  is required so for our purposes reserve a MEBIBYTE in front of the partition.
+			//  NOTE:  This logic also contained in Dialog_Base_Partition::MB_Needed_for_Boot_Record
+			if (   (   selected_partition .inside_extended
+			        && selected_partition .type == TYPE_UNALLOCATED
+			       )
+			    || ( selected_partition .type == TYPE_LOGICAL )
+			                                     /* Beginning of disk device */
+			    || ( selected_partition .sector_start <= (MEBIBYTE / selected_partition .sector_size) )
 			   )
-				required_size += devices[ current_device ] .cylsize ;
+				required_size += MEBIBYTE;
 
-			if ( required_size <= selected_partition .get_length() )
+			//Determine if space is needed for the Extended Boot Record for a logical partition
+			//  after this partition.  Generally an an additional track or MEBIBYTE
+			//  is required so for our purposes reserve a MEBIBYTE in front of the partition.
+			if (   (   (   selected_partition .inside_extended
+			            && selected_partition .type == TYPE_UNALLOCATED
+			           )
+			        || ( selected_partition .type == TYPE_LOGICAL )
+			       )
+			    && ( selected_partition .sector_end
+			         < ( devices[ current_device ] .length
+			             - ( 2 * MEBIBYTE / devices[ current_device ] .sector_size )
+			           )
+			       )
+			   )
+				required_size += MEBIBYTE;
+
+			//Determine if space is needed for the backup partition on a GPT partition table
+			if (   ( devices[ current_device ] .disktype == "gpt" )
+			    && ( ( devices[ current_device ] .length - selected_partition .sector_end )
+			         < ( MEBIBYTE / devices[ current_device ] .sector_size )
+			       )
+			   )
+				required_size += MEBIBYTE ;
+
+			if ( required_size <= selected_partition .get_byte_length() )
 				allow_paste( true ) ;
 		}
 		
@@ -962,7 +960,7 @@ void Win_GParted::set_valid_operations()
 
 		//see if there is an copied partition and if it passes all tests
 		if ( ! copied_partition .get_path() .empty() &&
-		     copied_partition .get_length() <= selected_partition .get_length() &&
+		     copied_partition .get_byte_length() <= selected_partition .get_byte_length() &&
 		     selected_partition .status == GParted::STAT_REAL &&
 		     copied_partition != selected_partition )
 		     allow_paste( true ) ;
@@ -1404,11 +1402,12 @@ void Win_GParted::activate_resize()
 					selected_partition .Set_Unallocated( devices[ current_device ] .get_path(),
 									     selected_partition .sector_start,
 									     selected_partition .sector_end,
+									     devices[current_device] .sector_size,
 									     selected_partition .inside_extended ) ;
 
 					Operation * operation = new OperationCreate( devices[ current_device ],
-							 			     selected_partition,
-							 			     dialog .Get_New_Partition() ) ;
+										     selected_partition,
+										     dialog .Get_New_Partition( devices[ current_device ] .sector_size ) ) ;
 					operation ->icon = render_icon( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU );
 
 					Add_Operation( operation ) ;
@@ -1420,8 +1419,8 @@ void Win_GParted::activate_resize()
 		else//normal move/resize on existing partition
 		{
 			Operation * operation = new OperationResizeMove( devices[ current_device ],
-					 			         selected_partition,
-							     		 dialog .Get_New_Partition() );
+								         selected_partition,
+								         dialog .Get_New_Partition( devices[ current_device ] .sector_size) );
 			operation ->icon = render_icon( Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_MENU );
 
 			Add_Operation( operation ) ;
@@ -1460,9 +1459,9 @@ void Win_GParted::activate_paste()
 				dialog .hide() ;
 
 				Operation * operation = new OperationCopy( devices[ current_device ],
-					 	       			   selected_partition,
-						       			   dialog .Get_New_Partition(),
-						       			   copied_partition ) ;
+									   selected_partition,
+									   dialog .Get_New_Partition( devices[ current_device ] .sector_size ),
+									   copied_partition ) ;
 				operation ->icon = render_icon( Gtk::Stock::COPY, Gtk::ICON_SIZE_MENU );
 
 				Add_Operation( operation ) ;
@@ -1527,8 +1526,8 @@ void Win_GParted::activate_new()
 			
 			new_count++ ;
 			Operation *operation = new OperationCreate( devices[ current_device ],
-							 	    selected_partition,
-							 	    dialog .Get_New_Partition() ) ;
+								    selected_partition,
+								    dialog .Get_New_Partition( devices[ current_device ] .sector_size ) ) ;
 			operation ->icon = render_icon( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU );
 
 			Add_Operation( operation );
@@ -1581,7 +1580,7 @@ void Win_GParted::activate_delete()
 		dialog .set_title( String::ucompose( _("Delete %1 (%2, %3)"), 
 						     selected_partition .get_path(), 
 						     Utils::get_filesystem_string( selected_partition .filesystem ),
-						     Utils::format_size( selected_partition .get_length() ) ) );
+						     Utils::format_size( selected_partition .get_sector_length(), selected_partition .sector_size ) ) );
 		dialog .add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 		dialog .add_button( Gtk::Stock::DELETE, Gtk::RESPONSE_OK );
 	
@@ -1640,8 +1639,8 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 	//check for some limits...
 	fs = gparted_core .get_fs( new_fs ) ;
 	
-	if ( ( selected_partition .get_length() < fs .MIN ) ||
-	     ( fs .MAX && selected_partition .get_length() > fs .MAX ) )
+	if ( ( selected_partition .get_byte_length() < fs .MIN ) ||
+	     ( fs .MAX && selected_partition .get_byte_length() > fs .MAX ) )
 	{
 		Gtk::MessageDialog dialog( *this,
 					   String::ucompose( _("Cannot format this file system to %1."),
@@ -1651,16 +1650,16 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 					   Gtk::BUTTONS_OK,
 					   true );
 
-		if ( selected_partition .get_length() < fs .MIN )
+		if ( selected_partition .get_byte_length() < fs .MIN )
 			dialog .set_secondary_text( String::ucompose( 
 						_( "A %1 file system requires a partition of at least %2."),
 						Utils::get_filesystem_string( new_fs ),
-						Utils::format_size( fs .MIN ) ) );
+						Utils::format_size( fs .MIN, 1 /* Byte */ ) ) );
 		else
 			dialog .set_secondary_text( String::ucompose( 
 						_( "A partition with a %1 file system has a maximum size of %2."),
 						Utils::get_filesystem_string( new_fs ),
-						Utils::format_size( fs .MAX ) ) );
+						Utils::format_size( fs .MAX, 1 /* Byte */ ) ) );
 		
 		dialog .run() ;
 		return ;
@@ -1668,14 +1667,15 @@ void Win_GParted::activate_format( GParted::FILESYSTEM new_fs )
 	
 	//ok we made it.  lets create an fitting partition object
 	Partition part_temp ;
-	part_temp .Set( devices[ current_device ] .get_path(), 
-			selected_partition .get_path(), 
-			selected_partition .partition_number, 
+	part_temp .Set( devices[ current_device ] .get_path(),
+			selected_partition .get_path(),
+			selected_partition .partition_number,
 			selected_partition .type,
-			new_fs, 
+			new_fs,
 			selected_partition .sector_start,
-			selected_partition .sector_end, 
-			selected_partition .inside_extended, 
+			selected_partition .sector_end,
+			devices[ current_device ] .sector_size,
+			selected_partition .inside_extended,
 			false ) ;
 	 
 	part_temp .status = GParted::STAT_FORMATTED ;
@@ -1969,14 +1969,15 @@ void Win_GParted::activate_label_partition()
 		dialog .hide() ;
 		//Make a duplicate of the selected partition (used in UNDO)
 		Partition part_temp ;
-		part_temp .Set( devices[ current_device ] .get_path(), 
-				selected_partition .get_path(), 
-				selected_partition .partition_number, 
+		part_temp .Set( devices[ current_device ] .get_path(),
+				selected_partition .get_path(),
+				selected_partition .partition_number,
 				selected_partition .type,
-				selected_partition .filesystem, 
+				selected_partition .filesystem,
 				selected_partition .sector_start,
-				selected_partition .sector_end, 
-				selected_partition .inside_extended, 
+				selected_partition .sector_end,
+				devices[ current_device ] .sector_size,
+				selected_partition .inside_extended,
 				false ) ;
 
 		part_temp .label = dialog .get_new_label();
