@@ -73,7 +73,7 @@ void ext3::set_used_sectors( Partition & partition )
 			S = -1 ;
 
 		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
+			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
 	}
 	else
 	{
@@ -117,7 +117,7 @@ bool ext3::resize( const Partition & partition_new, OperationDetail & operationd
 	
 	if ( ! fill_partition )
 		str_temp += " " + Utils::num_to_str( Utils::round( Utils::sector_to_unit( 
-					partition_new .get_length(), GParted::UNIT_KIB ) ) -1 ) + "K" ; 
+					partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) -1 ) + "K" ; 
 		
 	return ! execute_command( str_temp, operationdetail ) ;
 }
