@@ -71,7 +71,7 @@ void ntfs::set_used_sectors( Partition & partition )
 			N = -1 ;
 
 		if ( N > -1 )
-			partition .set_used( Utils::round( N / 512.0 ) ) ; 
+			partition .set_used( Utils::round( N / double(partition .sector_size) ) ) ; 
 	}
 	else
 	{
@@ -118,7 +118,7 @@ bool ntfs::resize( const Partition & partition_new, OperationDetail & operationd
 	{
 		str_temp += " -s " ;
 		str_temp += Utils::num_to_str( Utils::round( Utils::sector_to_unit(
-				partition_new .get_length(), GParted::UNIT_BYTE ) ) -1 ) ;
+				partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) -1 ) ;
 	}
 	
 	//simulation..
