@@ -57,7 +57,8 @@ FS reiserfs::get_filesystem_support()
 		fs .move = GParted::FS::GPARTED ;
 	}
 
-	fs .MIN = 32 * MEBIBYTE ;
+	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
+	fs .MIN = 34 * MEBIBYTE ;
 	
 	return fs ;
 }
@@ -77,7 +78,7 @@ void reiserfs::set_used_sectors( Partition & partition )
 			N = -1 ;
 
 		if ( N > -1 && S > -1 )
-			partition .Set_Unused( Utils::round( N * ( S / 512.0 ) ) ) ;
+			partition .Set_Unused( Utils::round( N * ( S / double(partition .sector_size) ) ) ) ;
 	}
 	else
 	{
@@ -124,7 +125,7 @@ bool reiserfs::resize( const Partition & partition_new, OperationDetail & operat
 	{
 		str_temp += " -s " ;
 		str_temp += Utils::num_to_str( Utils::round( Utils::sector_to_unit(
-				partition_new .get_length(), GParted::UNIT_BYTE ) ) -1 ) ;
+				partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) -1 ) ;
 	}
 
 	exit_status = execute_command( str_temp, operationdetail ) ;
